/***************************************************************************
                          dlg_newmatch.h  -  description
                             -------------------
    begin                : Tue Jun 25 2002
    copyright            : (C) 2003 by Troy Corbin Jr.
    email                : tcorbin@users.sf.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DLG_NEWMATCH_H
#define DLG_NEWMATCH_H

#include <tqwidget.h>
#include <kdialogbase.h>

#include "match_param.h"

/**
  *@author Troy Corbin Jr.
  */

class dlg_selectengine;
class dlg_selectemail;
class resource;
class TQLabel;
class TQSpinBox;
class TQRadioButton;
class TQCheckBox;
class TQVBox;
class TQHBox;
class TQGrid;
class TQButtonGroup;
class TQGroupBox;
class KComboBox;

class dlg_newmatch : public KDialogBase
{
	TQ_OBJECT
  
	private:
		resource					*myResource;
		match_param				*Param;
		dlg_selectengine	*EngineSelect;
		dlg_selectemail		*EmailSelect;

    TQHBox             *BOX_Parent;
	    TQVBox             *BOX_Players;
		    TQGroupBox         *BOX_White;
			    TQLabel            *IMAGE_White;
			    TQVBox             *BOX_White_Detail;
				    TQLabel            *LABEL_White_Name;
				    TQButtonGroup      *GROUP_White_Type;
					    TQRadioButton      *RADIO_White_Human;
					    TQRadioButton      *RADIO_White_PC;
					    TQRadioButton      *RADIO_White_Email;
	    TQGrid             *GRID_White_Time;
		    TQLabel            *LABEL_White_Base;
		    TQSpinBox          *SPIN_White_Base;
		    TQLabel            *LABEL_White_Inc;
		    TQSpinBox          *SPIN_White_Inc;
		    TQLabel            *LABEL_White_Moves;
		    TQSpinBox          *SPIN_White_Moves;
		    TQGroupBox         *BOX_Black;
			    TQLabel            *IMAGE_Black;
			    TQVBox             *BOX_Black_Detail;
				    TQLabel            *LABEL_Black_Name;
				    TQButtonGroup      *GROUP_Black_Type;
					    TQRadioButton      *RADIO_Black_Human;
					    TQRadioButton      *RADIO_Black_PC;
					    TQRadioButton      *RADIO_Black_Email;
	    TQGrid             *GRID_Black_Time;
		    TQLabel            *LABEL_Black_Base;
		    TQSpinBox          *SPIN_Black_Base;
		    TQLabel            *LABEL_Black_Inc;
		    TQSpinBox          *SPIN_Black_Inc;
		    TQLabel            *LABEL_Black_Moves;
		    TQSpinBox          *SPIN_Black_Moves;

  public:
                      dlg_newmatch(TQWidget *parent=0, const char *name=0, resource *Rsrc=0);
                      ~dlg_newmatch();
                      match_param* paramaters( void ) { return Param; }
  protected slots:
    void              slotWhiteType( int );
    void              slotWhiteBase( int );
    void              slotWhiteMoves( int );
    void              slotWhiteInc( int );

    void              slotBlackType( int );
    void              slotBlackBase( int );
    void              slotBlackMoves( int );
    void              slotBlackInc( int );

		void							slotReparse( void );

  protected:
    void              setTCP( void );
    void              setTypes( void );
    void              setImages( void );
    void              setNames( void );
};

#endif
